-- A2A Cessna 182 --
-- version 2.0
-- by Guenter Steiner --

--
-- ## System functions ###############

function InitVars ()
    -- uncomment to disable display
    --AutopilotDisplayBlocked ()

    AutoDisplay = false -- disable default AP knob functions
    SPD_CRS_replace = true -- replace SPD indication with CRS indication for bush planes
    silence = 0

    -- disable auto-restore for EFIS modes
    ipc.set("EFISrestore", 0)

    -- units
    A2AUnits = ipc.readLvar("Units")

    temp_units = A2AUnits -- 0 - C, 1 - F
    egt_units = A2AUnits  -- 0 - C, 1 - F
    carb_units = A2AUnits -- 0 - C, 1 - F

    if RADIOS ~= nil then -- prevent error on joysticks-only setup
        RADIOS["ADF1 Swap"]	=  A182_ADFbuttonFrq_click
        RADIOS["ADF ."]	=  A182_ADF_select_x
    end

    -- baro mode
    baro_mode = 1  -- 0 = inHG, 1 = hPa, 2 = mmHG
end

------------------------------------------------------------------

function Timer ()
    if ipc.get("DSPmode") == 1 then
        HDGvar = ipc.readLvar("AutopilotHeadingBug")
        DspHDG(HDGvar)
    end
    AdditionalInfo ()
end

function AdditionalInfo ()
    local ias = math.floor(ipc.readUW("02BC")/128)
    local overspeed = ''
    local ap = 'ap'
    local tx = ipc.readLvar("XpdrModeKnobPos")
    -- units
    A2AUnits = ipc.readLvar("Units")

    temp_units = A2AUnits -- 0 - C, 1 - F
    egt_units = A2AUnits  -- 0 - C, 1 - F
    carb_units = A2AUnits -- 0 - C, 1 - F

    -- Cabin Temp
    local cab
    if temp_units == 1 then
        -- C
        cab = tostring(round(ipc.readLvar("CabinTemp"))) .. 'C'
    else
        -- F
        cab = tostring(round(ipc.readLvar("CabinTemp") * 1.8 + 32)) .. 'F'
    end
    -- leading spaces
    while string.len(cab) < 4 do cab = " " .. cab end

    -- Power (in HP)
    EngHP = round(ipc.readLvar("Eng1_HorsepowerSmooth"))

    -- Flaps
    local flaps = ipc.readLvar("LandFlapsPos")
    if flaps < 0 then flaps = 0 end
    --if flaps == 0 then flaptxt = "^" end

    -- Display for MCP2
    if not _MCP1() then
        -- show MCP2 Cabin Temp
        com.write(dev, "DSP7".. cab, 8)

        -- AP ALT hold on?
        ApAltCheck = ipc.readLvar("ApAltLight")
        if ApAltCheck == 1 then
            DspALT_AP_on ()
        else
            DspALT_AP_off ()
        end

        -- autopilot state
        ap = ipc.readUD(0x07BC)

        -- AP stby?
        if ap == 1 then
            com.write(dev, "A/TAP" , 8)
        elseif ap == 0 then
            com.write(dev, "A/T  " , 8)
        end

        -- Flaps
        com.write(dev, "F/DF" .. flaps , 8)
    end

    -- Flap restrictions
    if ias > 115 and flaps > 0 then
        overspeed = '!'
    end

    -- transponder state
    --if tx == 0 then
    --    tx = 'tx'
    --elseif tx == 1 then
    --    tx = 'ts'
    --elseif tx == 2 then
    --    tx = 'tt'
    --elseif tx == 3 then
    --    tx = 'TX'
    --elseif tx == 4 then
    --    tx = 'TA'
    --end

    -- CarbAir
    local carbair
    carbair = round(ipc.readLvar("Eng1_CarbAirTemp"))
    if carb_units == 1 then
        -- C
        carbairtxt = carbair .. 'C'
    else
        -- F
        carbairtxt = round(((carbair)*1.8 + 32)) .. 'F'
    end

    ------ cowlflap state
    CFstate = round(ipc.readLvar("Eng1_CowlFlapsLever"))
    cowlflaptxt = "Cowl " .. CFstate .. "%"
    if CFstate > 99 then
        cowlflaptxt = "Cwl " .. CFstate .. "%"
    end

    if not _MCP1() then
        UpperInfoLong = "Pwr " .. EngHP -- .. "hp"
        -- LowerInfoLong = "Crb " .. carbairtxt
        LowerInfoLong = cowlflaptxt

        FLIGHT_INFO1 = UpperInfoLong
        FLIGHT_INFO2 = LowerInfoLong
    else
        FLIGHT_INFO1 = "F:".. flaps .. overspeed
        -- second line is left for AP indication
    end

    DisplayResync ()

end

-- Override default ADF Select function
function A182_ADF_select_x ()
    if RADIOS_MODE ~= 3 then
        RADIOS_SUBMODE = 2
    end

    RADIOS_MODE = 3 -- ADF

    if RADIOS_SUBMODE == 2 then
    	ipc.sleep(50)
        com.write(dev, "adfxxxxx", 8)
        Default_ADF_1_init (true)
        RADIOS_SUBMODE = 1

        if ipc.readLvar("AdfFrqButton") == 0 then
            A182_ADFbuttonFrq_click ()
        else
            A182_ADFbuttonFrq_click ()
        end
    else
        A182_ADFbuttonFrq_click ()
    end
   	ipc.sleep(50)
end

-- ## Autopilot KAP140 ###############

function KAP140_AP_Button_on ()
    -- autopilot state
    ap =  ipc.readUD(0x07BC)
    DspShow ("AP", "on")
    if ap == 0 then
        ipc.writeLvar("kap140_ap_button", 1)
        ipc.sleep(1000)
        ipc.writeLvar("kap140_ap_button", 0)
    end
end

function KAP140_AP_Button_off ()
    -- autopilot state
    ap =  ipc.readUD(0x07BC)
    DspShow ("AP", "off")
    if ap == 1 then
        ipc.writeLvar("kap140_ap_button", 1)
        ipc.sleep(1000)
        ipc.writeLvar("kap140_ap_button", 0)
    end
end

function KAP140_AP_Button_toggle ()
    -- autopilot state
    ap =  ipc.readUD(0x07BC)

    if ap == 1 then
        DspShow ("AP", "off")
    elseif ap == 0 then
        DspShow ("AP", "on")
    end
    ipc.writeLvar("kap140_ap_button", 1)
    ipc.sleep(1000)
    ipc.writeLvar("kap140_ap_button", 0)
end

---

function KAP140_AP_Button_hdg ()
    ipc.writeLvar("kap140_hdg_button", 1)
    ipc.writeLvar("kap140_hdg", 1)
    --DspShow ("Hdg", "hold")
    _sleep(50,150)
    ipc.writeLvar("kap140_hdg_button", 0)
end

function KAP140_AP_HeadingBug_inc ()
    HDGvar = ipc.readLvar("AutopilotHeadingBug")
    if HDGvar >= 359 then HDGvar = -1 end
    ipc.writeLvar("AutopilotHeadingBug", HDGvar +1)
    HDGvar = ipc.readLvar("AutopilotHeadingBug")
    DspHDG(HDGvar)
end

function KAP140_AP_HeadingBug_incfast ()
    HDGvar = ipc.readLvar("AutopilotHeadingBug")
    if HDGvar >= 359 then HDGvar = -1 end
    ipc.writeLvar("AutopilotHeadingBug", HDGvar +10)
    HDGvar = ipc.readLvar("AutopilotHeadingBug")
    DspHDG(HDGvar)
end

function KAP140_AP_HeadingBug_dec ()
    HDGvar = ipc.readLvar("AutopilotHeadingBug")
    if HDGvar <= 0 then HDGvar = 360 end
    ipc.writeLvar("AutopilotHeadingBug", HDGvar -1)
    HDGvar = ipc.readLvar("AutopilotHeadingBug")
    DspHDG(HDGvar)
end

function KAP140_AP_HeadingBug_decfast ()
    HDGvar = ipc.readLvar("AutopilotHeadingBug")
    if HDGvar <= 0 then HDGvar = 360 end
    ipc.writeLvar("AutopilotHeadingBug", HDGvar -10)
    HDGvar = ipc.readLvar("AutopilotHeadingBug")
    DspHDG(HDGvar)
end

function KAP140_AP_Button_nav ()
    ipc.writeLvar("kap140_nav_button", 1)
    ipc.writeLvar("kap140_nav", 1)
    --DspShow ("nav", "hold")
    _sleep(50,150)
    ipc.writeLvar("kap140_nav_button", 0)

      -- blink HDG
    if dev == 0 then return end

   	ipc.sleep(30)
    com.write(dev, "DSP4    " .. s, 8)
   	ipc.sleep(300)
    com.write(dev, "DSP4 HDG" .. s, 8)
   	ipc.sleep(300)
    com.write(dev, "DSP4    " .. s, 8)
   	ipc.sleep(300)
    com.write(dev, "DSP4 HDG" .. s, 8)
   	ipc.sleep(300)
    com.write(dev, "DSP4    " .. s, 8)
   	ipc.sleep(300)
    com.write(dev, "DSP4 HDG" .. s, 8)

    DspHideCursor ()
end

function KAP140_AP_Button_apr ()
    ipc.writeLvar("kap140_apr_button", 1)
    ipc.writeLvar("kap140_apr", 1)
    --DspShow ("apr", "hold")
    _sleep(50,150)
    ipc.writeLvar("kap140_apr_button", 0)
end

function KAP140_AP_Button_rev ()
    ipc.writeLvar("kap140_rev_button", 1)
    ipc.writeLvar("kap140_rev", 1)
    --DspShow ("rev", "hold")
    _sleep(50,150)
    ipc.writeLvar("kap140_rev_button", 0)
end

function KAP140_AP_Button_alt ()
    ipc.writeLvar("kap140_alt_button", 1)
    ipc.writeLvar("kap140_alt", 1)
    -- _AP_VS_VAR_SET_ENGLISH(1)
    --DspShow ("Alt", "hold")
    _sleep(50,150)
    ipc.writeLvar("kap140_alt_button", 0)
end

function KAP140_AP_Button_arm ()
    ipc.writeLvar("kap140_arm_button", 1)
    ipc.writeLvar("kap140_arm", 1)
    --DspShow ("Alt", "arm")
    _sleep(50,150)
    ipc.writeLvar("kap140_arm_button", 0)
end

function KAP140_AP_Button_baro ()
    ipc.writeLvar("kap140_baro_button", 1)
    ipc.writeLvar("kap140_baro", 1)
    --DspShow ("baro", "hold")
    _sleep(50,150)
    ipc.writeLvar("kap140_baro_button", 0)
end

function KAP140_AP_Button_up ()
    ipc.writeLvar("kap140_up_button", 1)
    DspShow ("Vs", "up")
    _sleep(50,150)
    ipc.writeLvar("kap140_up_button", 0)
end

function KAP140_AP_Button_dn ()
    ipc.writeLvar("kap140_dn_button", 1)
    DspShow ("Vs", "dn")
    _sleep(50,150)
    ipc.writeLvar("kap140_dn_button", 0)
end

function KAP140_AP_InnerKnob_plus ()
    ipc.writeLvar("kap140_InnerKnob", 1)
    ipc.sleep(50)
    DspALT(ipc.readLvar("AutopilotAltAlerter")/100)
end

function KAP140_AP_InnerKnob_minus ()
    ipc.writeLvar("kap140_InnerKnob", -1)
    ipc.sleep(50)
    DspALT(ipc.readLvar("AutopilotAltAlerter")/100)
end

function KAP140_AP_OuterKnob_plus ()
    ipc.writeLvar("kap140_OuterKnob", 1)
    ipc.sleep(50)
    DspALT(ipc.readLvar("AutopilotAltAlerter")/100)
end

function KAP140_AP_OuterKnob_minus ()
    ipc.writeLvar("kap140_OuterKnob", -1)
    ipc.sleep(50)
    DspALT(ipc.readLvar("AutopilotAltAlerter")/100)
end

-- ## Autopilot knobs ###############

function A182_AP_HDG_plus (a, b, c)
    HDG_plus (a, b, c)
    if not _MCP1 () then DspHDG(HDG) end
end

function A182_AP_HDG_plusfast (a, b, c)
    HDG_plusfast (a, b, c)
    if not _MCP1 () then DspHDG(HDG) end
end


function A182_AP_HDG_minus (a, b, c)
    HDG_minus (a, b, c)
    if not _MCP1 () then DspHDG(HDG) end
end

function A182_AP_HDG_minusfast (a, b, c)
    HDG_minusfast (a, b, c)
    if not _MCP1 () then DspHDG(HDG) end
end

function A182_AP_ALT_plus (a, b, c)
    --if c == nil then
        A182_AP_InnerKnob_plus ()
    --else
    --    if _MCP2 () then
    --        ipc.writeLvar("AutopilotAltAlerter", c * 100)
    --        DspALT(ALT)
    --    else
    --        ipc.writeLvar("AutopilotAltAlerter", c * 10)
    --    end
    --end

end

function A182_AP_ALT_plusfast (a, b, c)

    --if c == nil then
        A182_AP_OuterKnob_plus ()
    --else
    --    if _MCP2 () then
    --        ipc.writeLvar("AutopilotAltAlerter", c * 100)
    --        DspALT(ALT)
    --   else
    --        ipc.writeLvar("AutopilotAltAlerter", c * 10)
    --    end
    --end

end

function A182_AP_ALT_minus (a, b, c)

    --if c == nil then
        A182_AP_InnerKnob_minus ()
    --else
    --    if _MCP2 () then
    --        ipc.writeLvar("AutopilotAltAlerter", c * 100)
    --        DspALT(ALT)
    --    else
    --        ipc.writeLvar("AutopilotAltAlerter", c * 10)
    --    end
    --end

end

function A182_AP_ALT_minusfast (a, b, c)

    --if c == nil then
        A182_AP_OuterKnob_minus ()
    --else
    --    if _MCP2 () then
    --        ipc.writeLvar("AutopilotAltAlerter", c * 100)
    --        DspALT(ALT)
    --    else
    --        ipc.writeLvar("AutopilotAltAlerter", c * 10)
    --    end
    --end

end

function A182_AP_VS_plus (a, b, c)

    --if c == nil then
        A182_AP_Button_up ()
    --else
    --    if _MCP2 () then
    --        if c > 15 then c = 15 end
    --        VVS_plus (a, b, c)
    --        DspVVS(c)
    --    else
    --        VVS_plus ()
    --    end
    --end

end

function A182_AP_VS_minus (a, b, c)

    --if c == nil then
        A182_AP_Button_dn ()
    --else
    --    if _MCP2 () then
    --        if c < -20 then c = -20 end
    --        VVS_minus (a, b, c)
    --        DspVVS(c)
    --    else
    --        VVS_minus ()
    --    end
    --end

end

-- ## Autopilot buttons ###############

function A182_AP_Button_hdg ()
      ipc.writeLvar("kap140_hdg_button", 1)
      ipc.writeLvar("kap140_hdg", 1)
      --DspShow ("Hdg", "hold")
      _sleep(50,150)
      ipc.writeLvar("kap140_hdg_button", 0)
end

function A182_AP_Button_nav ()
    ipc.writeLvar("kap140_nav_button", 1)
    ipc.writeLvar("kap140_nav", 1)
    --DspShow ("nav", "hold")
    _sleep(50,150)
    ipc.writeLvar("kap140_nav_button", 0)

      -- blink HDG
    if dev == 0 then return end

   	ipc.sleep(30)
    com.write(dev, "DSP4    " .. s, 8)
   	ipc.sleep(300)
    com.write(dev, "DSP4HDG " .. s, 8)
   	ipc.sleep(300)
    com.write(dev, "DSP4    " .. s, 8)
   	ipc.sleep(300)
    com.write(dev, "DSP4HDG " .. s, 8)
   	ipc.sleep(300)
    com.write(dev, "DSP4    " .. s, 8)
   	ipc.sleep(300)
    com.write(dev, "DSP4HDG " .. s, 8)

    DspHideCursor ()

end

function A182_AP_Button_apr ()
      ipc.writeLvar("kap140_apr_button", 1)
      ipc.writeLvar("kap140_apr", 1)
      --DspShow ("apr", "hold")
      _sleep(50,150)
      ipc.writeLvar("kap140_apr_button", 0)
end

function A182_AP_Button_rev ()
      ipc.writeLvar("kap140_rev_button", 1)
      ipc.writeLvar("kap140_rev", 1)
      --DspShow ("rev", "hold")
      _sleep(50,150)
      ipc.writeLvar("kap140_rev_button", 0)
end

function A182_AP_Button_alt ()
      ipc.writeLvar("kap140_alt_button", 1)
      ipc.writeLvar("kap140_alt", 1)
      -- _AP_VS_VAR_SET_ENGLISH(1)
      --DspShow ("Alt", "hold")
      _sleep(50,150)
      ipc.writeLvar("kap140_alt_button", 0)
end

function A182_AP_Button_arm ()
      ipc.writeLvar("kap140_arm_button", 1)
      ipc.writeLvar("kap140_arm", 1)
      --DspShow ("Alt", "arm")
      _sleep(50,150)
      ipc.writeLvar("kap140_arm_button", 0)
end


function A182_AP_Button_baro ()
      ipc.writeLvar("kap140_baro_button", 1)
      ipc.writeLvar("kap140_baro", 1)
      --DspShow ("baro", "hold")
      _sleep(50,150)
      ipc.writeLvar("kap140_baro_button", 0)
end

function A182_AP_Button_up ()
      ipc.writeLvar("kap140_up_button", 1)
      DspShow ("Vs", "up")
      _sleep(50,150)
      ipc.writeLvar("kap140_up_button", 0)
end

function A182_AP_Button_dn ()
      ipc.writeLvar("kap140_dn_button", 1)
      DspShow ("Vs", "dn")
      _sleep(50,150)
      ipc.writeLvar("kap140_dn_button", 0)
end

function A182_AP_InnerKnob_plus ()
      ipc.writeLvar("kap140_InnerKnob", 1)
      DspALT(ipc.readLvar("AutopilotAltAlerter")/100)
end

function A182_AP_InnerKnob_minus ()
      ipc.writeLvar("kap140_InnerKnob", -1)
      DspALT(ipc.readLvar("AutopilotAltAlerter")/100)
end

function A182_AP_OuterKnob_plus ()
      ipc.writeLvar("kap140_OuterKnob", 1)
      DspALT(ipc.readLvar("AutopilotAltAlerter")/100)
end

function A182_AP_OuterKnob_minus ()
      ipc.writeLvar("kap140_OuterKnob", -1)
      DspALT(ipc.readLvar("AutopilotAltAlerter")/100)
end

-- ## Magnetos ###############

function A182_Magneto_start ()
    --_MAGNETO1_SET (4)
    DspShow ("MAG", "Strt", "Magneto", " Start")
    --ipc.sleep(50)
    ipc.writeLvar("Eng1_StarterSwitch", 1)

    ipc.control(66300)
    ipc.control(66127)
end

function A2A_Magneto1_both ()
    _MAGNETO1_SET (3)
    DspShow ("MAG", "both", "Magneto", " both")
end

function A2A_Magneto1_left ()
    _MAGNETO1_SET (2)
    DspShow ("MAG", "left", "Magneto", " left")
end

function A2A_Magneto1_right ()
    _MAGNETO1_SET (1)
    DspShow ("MAG", "rght", "Magneto", " right")
end

function A2A_Magneto1_off ()
    _MAGNETO1_SET (0)
    DspShow ("MAG", "Stop", "Magneto", " Stop")
end

function A2A_Magneto1_inc ()
    local t = ipc.readLvar('Magnetos1')
    if t < 4 then t = t + 1 end
    _MAGNETO1_SET (t)

    if t == 0 then
        DspShow ("MAG", "Off")
    elseif t == 1 then
        DspShow ("MAG", "Rght")
    elseif t == 2 then
        DspShow ("MAG", "Left")
    elseif t == 3 then
        DspShow ("MAG", "Both")
    elseif t == 4 then
        DspShow ("MAG", "Strt")
    end

    _sleep(100)
end

function A2A_Magneto1_dec ()
    local t = ipc.readLvar('Magnetos1')
    if t > 0 then t = t - 1 end
    _MAGNETO1_SET (t)

    if t == 0 then
        DspShow ("MAG", "Off")
    elseif t == 1 then
        DspShow ("MAG", "Rght")
    elseif t == 2 then
        DspShow ("MAG", "Left")
    elseif t == 3 then
        DspShow ("MAG", "Both")
    elseif t == 4 then
        DspShow ("MAG", "Strt")
    end

    _sleep(100)
end

-- ## Electrics ###############

function A2A_Battery_on ()
    ipc.writeLvar('Battery1Switch', 1)
    DspShow ("BATT", "ON", "Battery" ," on")
end

function A2A_Battery_off ()
    ipc.writeLvar('Battery1Switch', 0)
    DspShow ("BATT", "OFF", "Battery" ," off")
end

function A2A_Battery_toggle ()
	if ipc.readLvar('Battery1Switch') == 0 then
        A2A_Battery_on ()
	else
        A2A_Battery_off ()
	end
end

function A182_AnnLights_test ()
    local i
    ipc.writeLvar('AnnPanelTestSwitchDrag', 1)
    ipc.writeLvar('AnnPanelTestSwitchPercent', 100)
    for i = 0,70,1 do
        ipc.writeLvar('AnnunciatorPanelTestSwitch', 2)
    end
    ipc.writeLvar('AnnPanelTestSwitchDrag', 0)
end

function A182_AnnLights_dim ()
    ipc.writeLvar('AnnunciatorPanelTestSwitch', 0)
    ipc.writeLvar('AnnPanelTestSwitchPercent', 0)
end

function A182_AnnLights_bright ()
    ipc.writeLvar('AnnunciatorPanelTestSwitch', 1)
    ipc.writeLvar('AnnPanelTestSwitchPercent', 50)
end

function A182_AnnLights_toggle ()
    if ipc.readLvar('AnnunciatorPanelTestSwitch') == 0 then
        A182_AnnLights_test ()
    elseif ipc.readLvar('AnnunciatorPanelTestSwitch') == 1 then
        A182_AnnLights_dim ()
    else
        A182_AnnLights_bright ()
    end
end

function A182_Alternator_on ()
    ipc.writeLvar('Eng1_GeneratorSwitch', 1)
    DspShow ("GEN", "ON")
end

function A182_Alternator_off ()
    ipc.writeLvar('Eng1_GeneratorSwitch', 0)
    DspShow ("GEN", "OFF")
end

function A182_Alternator_toggle ()
	if ipc.readLvar('Eng1_GeneratorSwitch') == 0 then
        A182_Alternator_on ()
	else
        A182_Alternator_off ()
	end
end

-- ## Avionics ###############

function A2A_Avionics_on ()
    _AVIONICS_MASTER_SET (1)
    DspShow ("MAST", "ON", "AvioMstr", " on")
end

function A2A_Avionics_off ()
    _AVIONICS_MASTER_SET (0)
    DspShow ("MAST", "OFF", "AvioMstr", " off")
end

function A2A_Avionics_toggle ()
    if ipc.readDD(0x2E80) == 0 then
        A2A_Avionics_on ()
	else
        A2A_Avionics_off ()
	end
end

function A2A_Com1_on ()
    ipc.writeLvar("Com1OnOff", 1)
    DspShow ("COM1", "on")
end

function A2A_Com1_off ()
    ipc.writeLvar("Com1OnOff", 0)
    DspShow ("COM1", "off")
end

function A2A_Com1_toggle ()
	if _tl("Com1OnOff", 0) then
       A2A_Com1_on ()
	else
       A2A_Com1_off ()
	end
end

---

function A2A_Com2_on ()
    ipc.writeLvar("Com2OnOff", 1)
    DspShow ("COM2", "on")
end

function A2A_Com2_off ()
    ipc.writeLvar("Com2OnOff", 0)
    DspShow ("COM2", "off")
end

function A2A_Com2_toggle ()
	if _tl("Com2OnOff", 0) then
       A2A_Com2_on ()
	else
       A2A_Com2_off ()
	end
end

---

function A2A_ADF_on ()
    ipc.writeLvar("AdfOnOffKnob", 1)
    DspShow ("ADF", "on")
end

function A2A_ADF_off ()
    ipc.writeLvar("AdfOnOffKnob", 0)
    DspShow ("ADF", "off")
end

function A2A_ADF_toggle ()
	if _tl("AdfOnOffKnob", 0) then
       A2A_ADF_on ()
	else
       A2A_ADF_off ()
	end
end

---

function A2A_DMEKN62_on ()
    ipc.writeLvar("kn62OnOff", 1)
    DspShow ("DME", "on")
end

function A2A_DMEKN62_off ()
    ipc.writeLvar("kn62OnOff", 0)
    DspShow ("DME", "off")
end

function A2A_DMEKN62_toggle ()
	if _tl("kn62OnOff", 0) then
       A2A_DMEKN62_on ()
	else
       A2A_DMEKN62_off ()
	end
end

--

function A2A_GPS_on ()
    ipc.writeLvar("GpsOnSwitch", 1)
    DspShow ("GPS", "on")
end

function A2A_GPS_off ()
    ipc.writeLvar("GpsOnSwitch", 0)
    DspShow ("GPS", "off")
end

function A2A_GPS_toggle ()
	if _tl("GpsOnSwitch", 0) then
       A2A_GPS_on ()
	else
       A2A_GPS_off ()
	end
end

function A2A_All_Radios_on ()
    --A2A_GPS_on ()
    --_sleep(100,200)
    A2A_Com1_on ()
    _sleep(100,200)
    A2A_Com2_on ()
    _sleep(100,200)
    A2A_ADF_on ()
    _sleep(100,200)
    A2A_DMEKN62_on ()
    --A2A_Transponder_on ()
end

function A2A_All_Radios_off ()
    -- A2A_GPS_off ()
    --_sleep(100,200)
    A2A_Com1_off ()
    _sleep(100,200)
    A2A_Com2_off ()
    _sleep(100,200)
    A2A_ADF_off ()
    _sleep(100,200)
    A2A_DMEKN62_off ()
    --A2A_Transponder_off ()
end

-- ## Fuel ###############

function A182_FuelPump_on ()
    ALL_FuelPumps_on ()
end

function A182_FuelPump_off ()
    ALL_FuelPumps_off ()
end

function A182_FuelPump_toggle ()
    ALL_FuelPumps_toggle ()
end

function A182_FuelSelector_show ()
    local t = ipc.readLvar('FSelC182State')

    if t == 1 then
        DspShow ("FUEL", "Left")
    elseif t == 2 then
        DspShow ("FUEL", "Both")
    elseif t == 3 then
        DspShow ("FUEL", "Rght", "  FUEL", "  Right")
    elseif t == 0 then
        DspShow ("FUEL", "Off")
    end
end

function A182_FuelSelector_inc ()
    local t = ipc.readLvar('FSelC182State')
    t = t + 1
    if t > 3 then t = 3 end
    ipc.writeLvar('FSelC182State', t)
    A182_FuelSelector_show ()
end

function A182_FuelSelector_dec ()
    local t = ipc.readLvar('FSelC182State')
    t = t - 1
    if t < 0 then t = 0 end
    ipc.writeLvar('FSelC182State', t)
    A182_FuelSelector_show ()
end

function A182_FuelSelector_left ()
    ipc.writeLvar('FSelC182State', 1)
    A182_FuelSelector_show ()
end

function A182_FuelSelector_right ()
    ipc.writeLvar('FSelC182State', 3)
    A182_FuelSelector_show ()
end

function A182_FuelSelector_both ()
    ipc.writeLvar('FSelC182State', 2)
    A182_FuelSelector_show ()
end

function A182_FuelSelector_off ()
    ipc.writeLvar('FSelC182State', 0)
    A182_FuelSelector_show ()
end

function A182_FuelSelector_toggle ()
    local f = ipc.readLvar('FSelC182State')
    if f == 0 then
        A182_FuelSelector_left ()
    elseif f == 1 then
        A182_FuelSelector_both ()
    elseif f == 2 then
        A182_FuelSelector_right ()
    elseif f == 3 then
        A182_FuelSelector_off ()
    end
end

-- ## ADF ###############

function A182_ADFbuttonAdf_on ()
    ipc.writeLvar("AdfAdfButton", 1)
end

function A182_ADFbuttonAdf_off ()
    ipc.writeLvar("AdfAdfButton", 0)
end

function A182_ADFbuttonAdf_toggle ()
    local b = ipc.readLvar("AdfAdfButton")
    b = 1 - b
    ipc.writeLvar("AdfAdfButton", b)
end

function A182_ADFbuttonBfo_on ()
    ipc.writeLvar("AdfBfoButton", 1)
    if _MCP1() then
        DspShow ("ADF", "BFO")
    else
        if RADIOS_MODE == 3 then
            DspRadioShort("BFO")
        else
            DspShow ("", "", "  ADF", " BFO on")
        end
    end
end

function A182_ADFbuttonBfo_off ()
    ipc.writeLvar("AdfBfoButton", 0)
    if _MCP1 () then
        DspShow ("ADF", "BFO")
    else
        if RADIOS_MODE == 3 then
            DspRadioShort("")
        else
            DspShow ("", "", "  ADF", " BFO off")
        end
    end
end

function A182_ADFbuttonBfo_toggle ()
    local b = ipc.readLvar("AdfBfoButton")
    if b == 1 then
        A182_ADFbuttonBfo_off ()
    else
        A182_ADFbuttonBfo_on ()
    end
end

function A182_ADFbuttonFrq_click ()
    ipc.writeLvar("AdfFrqButton", 1)
    if _MCP1 () then
        DspShow ("ADF", "<->")
    end
    _sleep(100,250)
    ipc.writeLvar("AdfFrqButton", 0)
    _sleep(50)

    if RADIOS_MODE == 3 then
        Default_ADF_1_init(true)
    end
end

function A182_ADFbuttonEt_click ()
    ipc.writeLvar("AdfFrqEtButton", 1)
    if _MCP1 () then
        DspShow ("ADF", " ET ")
    end
    _sleep(100,250)
    ipc.writeLvar("AdfFrqEtButton", 0)
end

function A182_ADFbuttonReset_click ()
    ipc.writeLvar("AdfFrqRstButton", 1)
    if _MCP1 () then
        DspShow ("ADF", "SET")
    end
    _sleep(100,250)
    ipc.writeLvar("AdfFrqRstButton", 0)
end

function A182_ADFbuttonReset_hold ()
    ipc.writeLvar("AdfFrqRstButton", 1)
    if _MCP1 () then
        DspShow ("ADF", "SET")
    end
    _sleep(2000,2500)
    ipc.writeLvar("AdfFrqRstButton", 0)
end

function A182_ADFident_on  ()
    ipc.control(65841)
    A182_ADFbuttonAdf_off ()
    if _MCP1 () then
        DspShow("ADF1","AUD")
    else
        DspRadioIdent_on ()
    end
end

function A182_ADFident_off  ()
    ipc.control(65836)
    A182_ADFbuttonAdf_on ()
    if _MCP1 () then
        DspShow("ADF1","OFF")
    else
        DspRadioIdent_off ()
    end
end

function A182_ADFident_toggle  ()
	if ipc.readLvar("AdfAdfButton") == 0 then
        A182_ADFident_off  ()
	else
        A182_ADFident_on  ()
	end
end

-- ## Transponder ###############

function A182_Transponder_cycle ()
    local x = ipc.readLvar("xpdr_onoff_knob_pos")
    x = x + 1
    if x > 4 then x = 0 end
    ipc.writeLvar("xpdr_onoff_knob_pos", x)
    A182_Transponder_show ()
end

function A182_Transponder_inc ()
    local x = ipc.readLvar("xpdr_onoff_knob_pos")
    x = x + 1
    if x > 4 then x = 4 end
    ipc.writeLvar("xpdr_onoff_knob_pos", x)
    A182_Transponder_show ()
end

function A182_Transponder_dec ()
    local x = ipc.readLvar("xpdr_onoff_knob_pos")
    x = x - 1
    if x < 0 then x = 0 end
    ipc.writeLvar("xpdr_onoff_knob_pos", x)
    A182_Transponder_show ()
end

function A182_Transponder_off ()
    ipc.writeLvar("xpdr_onoff_knob_pos", 0)
    A182_Transponder_show ()
end

function A182_Transponder_stby ()
    ipc.writeLvar("xpdr_onoff_knob_pos", 1)
    A182_Transponder_show ()
end

function A182_Transponder_test ()
    ipc.writeLvar("xpdr_onoff_knob_pos", 2)
    A182_Transponder_show ()
end

function A182_Transponder_on ()
    ipc.writeLvar("xpdr_onoff_knob_pos", 3)
    A182_Transponder_show ()
end

function A182_Transponder_alt ()
    ipc.writeLvar("xpdr_onoff_knob_pos", 4)
    A182_Transponder_show ()
end

function A182_Transponder_show ()
    local x = ipc.readLvar("xpdr_onoff_knob_pos")
    local xt, xtm
    if x == 0 then
        xt = "Off"
        xtm = "Off"
    elseif x == 1 then
        xt = "Stby"
        xtm = "Stby"
    elseif x == 2 then
        xt = "Test"
        xtm = "Test"
    elseif x == 3 then
        xt = "On"
        xtm = "On"
    elseif x == 4 then
        xt = "Alt"
        xtm = "Alt"
    end

    if _MCP1() then
        DspShow("XPDR", xt)
    else
        DspRadioShort(xtm)
    end

    DspRadioHideCursor ()
end

-- ## Lights ###############

function A182_BeaconLight_on ()
    Lights_BEACON_on ()
end

function A182_BeaconLight_off ()
    Lights_BEACON_off ()
end

function A182_BeaconLight_toggle ()
    Lights_BEACON_toggle ()
end

function A182_LandingLight_on ()
    Lights_LANDING_on ()
end

function A182_LandingLight_off ()
    Lights_LANDING_off ()
end

function A182_LandingLight_toggle ()
    Lights_LANDING_toggle ()
end

function A182_TaxiLight_on ()
    Lights_TAXI_on ()
end

function A182_TaxiLight_off ()
    Lights_TAXI_off ()
end

function A182_TaxiLight_toggle ()
    Lights_TAXI_toggle ()
end

function A182_NavLight_on ()
    Lights_NAV_on ()
end

function A182_NavLight_off ()
    Lights_NAV_off ()
end

function A182_NavLight_toggle ()
    Lights_NAV_toggle ()
end

function A182_StrobeLight_on ()
    Lights_STROBE_on ()
end

function A182_StrobeLight_off ()
    Lights_STROBE_off ()
end

function A182_StrobeLight_toggle ()
    Lights_STROBE_toggle ()
end

-- ## Cabin lights ###############

function test ()
    --ipc.writeLvar('FloodLight1Switch', 1)
    --ipc.writeLvar('FloodLight2Switch', 0)
    ipc.control(66376)

end

function A182_FloodLight_dim_on ()
     if ipc.readLvar('FloodLight2Switch') == 0 and
        ipc.readLvar('FloodLight1Switch') == 0
     then
        ipc.control(66579)
     elseif ipc.readLvar('FloodLight2Switch') == 1 and
        ipc.readLvar('FloodLight1Switch') == 1
     then
        ipc.control(66376)
     end
     DspShow ("Flod", "dim", "Flood", "dim on")
end

function A182_FloodLight_dim_off ()
     if ipc.readLvar('FloodLight2Switch') == 1 and
        ipc.readLvar('FloodLight1Switch') == 0 or
        ipc.readLvar('FloodLight2Switch') == 0 and
        ipc.readLvar('FloodLight1Switch') == 1
     then
        ipc.control(66579)
     end
     DspShow ("Flod", "dim", "Flood", "dim off")
end

function A182_FloodLight_dim_toggle ()
     if ipc.readLvar('FloodLight2Switch') == 0 and
        ipc.readLvar('FloodLight1Switch') == 0
     then
        ipc.control(66579)
        DspShow ("Flod", "dim", "Flood", "dim on")
     elseif ipc.readLvar('FloodLight2Switch') == 1 and
        ipc.readLvar('FloodLight1Switch') == 0 or
        ipc.readLvar('FloodLight2Switch') == 0 and
        ipc.readLvar('FloodLight1Switch') == 1
     then
        ipc.control(66579)
        DspShow ("Flod", "dim", "Flood", "dim off")
     end
end

function A182_FloodLight_bright_on ()
     if ipc.readLvar('FloodLight2Switch') == 1 and
        ipc.readLvar('FloodLight1Switch') == 0 or
        ipc.readLvar('FloodLight2Switch') == 0 and
        ipc.readLvar('FloodLight1Switch') == 1
     then
        ipc.control(66376)
     elseif ipc.readLvar('FloodLight2Switch') == 0 and
        ipc.readLvar('FloodLight1Switch') == 0
     then
        A182_FloodLight_dim_on ()
        ipc.control(66376)
     end
     DspShow ("Flod", "brgt", "Flood", "brgt on")
end

function A182_FloodLight_bright_off ()
     if ipc.readLvar('FloodLight2Switch') == 1 and
        ipc.readLvar('FloodLight1Switch') == 1
     then
        ipc.control(66376)
        ipc.sleep(50)
        A182_FloodLight_dim_off ()
     end
     DspShow ("Flod", "brgt", "Flood", "brgt off")
end

function A182_FloodLight_toggle ()
     if ipc.readLvar('FloodLight2Switch') == 0 and
        ipc.readLvar('FloodLight1Switch') == 0
     then
        A182_FloodLight_dim_on ()
     elseif ipc.readLvar('FloodLight2Switch') == 1 and
        ipc.readLvar('FloodLight1Switch') == 0 or
        ipc.readLvar('FloodLight2Switch') == 0 and
        ipc.readLvar('FloodLight1Switch') == 1
     then
        A182_FloodLight_bright_on ()
     else
        A182_FloodLight_bright_off ()
     end
end

function A182_PanelLight_on ()
    ipc.writeLvar('PanelLightKnob', 15)
    ipc.writeLvar('RadioLightKnob', 15)
    A182_PanelAndRadio_show ()
end

function A182_PanelLight_off ()
    ipc.writeLvar('PanelLightKnob', 0)
    ipc.writeLvar('RadioLightKnob', 0)
    A182_PanelAndRadio_show ()
end

function A182_PanelLight_toggle ()
	if _tl("PanelLightKnob", 0) then
        A182_PanelLight_on ()
	else
        A182_PanelLight_off ()
	end
end

-- ## Light knobs ###############

function A182_PanelLight_show ()
   local pl = round((ipc.readLvar('PanelLightKnob')/32)*100)
   DspShow ("Panl", pl .. "%")
end

function A182_PanelLight_plus ()
    local pl = ipc.readLvar('PanelLightKnob')
    if pl < 32 then
        pl = pl + 1
    end
    ipc.writeLvar('PanelLightKnob', pl)
    if ipc.get("silence") == 0 then
        A182_PanelLight_show ()
    end
end

function A182_PanelLight_plusfast ()
    local pl = ipc.readLvar('PanelLightKnob')
    if pl < 32 then
        pl = pl + 4
    end
    if pl > 32 then
        pl = 32
    end
    ipc.writeLvar('PanelLightKnob', pl)
    if ipc.get("silence") == 0 then
        A182_PanelLight_show ()
    end
end

function A182_PanelLight_minus ()
    local pl = ipc.readLvar('PanelLightKnob')
    if pl > 0 then
        pl = pl - 1
    end
    ipc.writeLvar('PanelLightKnob', pl)
    if ipc.get("silence") == 0 then
        A182_PanelLight_show ()
    end
end

function A182_PanelLight_minusfast ()
    local pl = ipc.readLvar('PanelLightKnob')
    if pl > 0 then
        pl = pl - 4
    end
    if pl < 0 then
        pl = 0
    end
    ipc.writeLvar('PanelLightKnob', pl)
    if ipc.get("silence") == 0 then
        A182_PanelLight_show ()
    end
end

--------

function A182_RadioLight_show ()
   local pl = round((ipc.readLvar('RadioLightKnob')/32)*100)
   DspShow ("Rdio", pl .. "%")
end

function A182_RadioLight_plus ()
    local pl = ipc.readLvar('RadioLightKnob')
    if pl < 32 then
        pl = pl + 1
    end
    ipc.writeLvar('RadioLightKnob', pl)
    if ipc.get("silence") == 0 then
        A182_RadioLight_show ()
    end
end

function A182_RadioLight_plusfast ()
    local pl = ipc.readLvar('RadioLightKnob')
    if pl < 32 then
        pl = pl + 4
    end
    if pl > 32 then
        pl = 32
    end
    ipc.writeLvar('RadioLightKnob', pl)
    if ipc.get("silence") == 0 then
        A182_RadioLight_show ()
    end
end

function A182_RadioLight_minus ()
    local pl = ipc.readLvar('RadioLightKnob')
    if pl > 0 then
        pl = pl - 1
    end
    ipc.writeLvar('RadioLightKnob', pl)
    if ipc.get("silence") == 0 then
        A182_RadioLight_show ()
    end
end

function A182_RadioLight_minusfast ()
    local pl = ipc.readLvar('RadioLightKnob')
    if pl > 0 then
        pl = pl - 4
    end
    if pl < 0 then
        pl = 0
    end
    ipc.writeLvar('RadioLightKnob', pl)
    if ipc.get("silence") == 0 then
        A182_RadioLight_show ()
    end
end

----

function A182_PanelAndRadio_show ()
     PnlL = round((ipc.readLvar('RadioLightKnob')/32)*100)
     RadioL = round((ipc.readLvar('PanelLightKnob')/32)*100)
     PnlRadioTxt = round((PnlL + RadioL)/2)
     DspShow ("Panl", PnlRadioTxt .. "%", "Pnl+Rdio", PnlRadioTxt .. "%")
end

function A182_PanelAndRadio_plus ()
    ipc.set("silence", 1)
    A182_PanelLight_plus ()
    A182_RadioLight_plus ()
    A182_PanelAndRadio_show ()
    ipc.set("silence", 0)
end

function A182_PanelAndRadio_plusfast ()
    ipc.set("silence", 1)
    A182_PanelLight_plusfast ()
    A182_RadioLight_plusfast ()
    A182_PanelAndRadio_show ()
    ipc.set("silence", 0)
end

function A182_PanelAndRadio_minus ()
    ipc.set("silence", 1)
    A182_PanelLight_minus ()
    A182_RadioLight_minus ()
    A182_PanelAndRadio_show ()
    ipc.set("silence", 0)
end

function A182_PanelAndRadio_minusfast ()
    ipc.set("silence", 1)
    A182_PanelLight_minusfast ()
    A182_RadioLight_minusfast ()
    A182_PanelAndRadio_show ()
    ipc.set("silence", 0)
end

----------

function A182_GlareshieldLight_show ()
   local pl = round((ipc.readLvar('GlareshieldLightKnob')/32)*100)
   DspShow ("Glre", pl .. "%")
end

function A182_GlareshieldLight_plus ()
    local pl = ipc.readLvar('GlareshieldLightKnob')
    if pl < 32 then
        pl = pl + 1
    end
    ipc.writeLvar('GlareshieldLightKnob', pl)
    if ipc.get("silence") == 0 then
        A182_GlareshieldLight_show ()
    end
end

function A182_GlareshieldLight_plusfast ()
    local pl = ipc.readLvar('GlareshieldLightKnob')
    if pl < 32 then
        pl = pl + 4
    end
    if pl > 32 then
        pl = 32
    end
    ipc.writeLvar('GlareshieldLightKnob', pl)
    if ipc.get("silence") == 0 then
        A182_GlareshieldLight_show ()
    end
end

function A182_GlareshieldLight_minus ()
    local pl = ipc.readLvar('GlareshieldLightKnob')
    if pl > 0 then
        pl = pl - 1
    end
    ipc.writeLvar('GlareshieldLightKnob', pl)
    if ipc.get("silence") == 0 then
        A182_GlareshieldLight_show ()
    end
end

function A182_GlareshieldLight_minusfast ()
    local pl = ipc.readLvar('GlareshieldLightKnob')
    if pl > 0 then
        pl = pl - 4
    end
    if pl < 0 then
        pl = 0
    end
    ipc.writeLvar('GlareshieldLightKnob', pl)
    if ipc.get("silence") == 0 then
        A182_GlareshieldLight_show ()
    end
end

-----

function A182_PedestalLight_show ()
   local pl = round((ipc.readLvar('PedestalLightKnob')/32)*100)
   DspShow ("Peds", pl .. "%")
end

function A182_PedestalLight_plus ()
    local pl = ipc.readLvar('PedestalLightKnob')
    if pl < 32 then
        pl = pl + 1
    end
    ipc.writeLvar('PedestalLightKnob', pl)
    if ipc.get("silence") == 0 then
        A182_PedestalLight_show ()
    end
end

function A182_PedestalLight_plusfast ()
    local pl = ipc.readLvar('PedestalLightKnob')
    if pl < 32 then
        pl = pl + 4
    end
    if pl > 32 then
        pl = 32
    end
    ipc.writeLvar('PedestalLightKnob', pl)
    if ipc.get("silence") == 0 then
        A182_PedestalLight_show ()
    end
end

function A182_PedestalLight_minus ()
    local pl = ipc.readLvar('PedestalLightKnob')
    if pl > 0 then
        pl = pl - 1
    end
    ipc.writeLvar('PedestalLightKnob', pl)
    if ipc.get("silence") == 0 then
        A182_PedestalLight_show ()
    end
end

function A182_PedestalLight_minusfast ()
    local pl = ipc.readLvar('PedestalLightKnob')
    if pl > 0 then
        pl = pl - 4
    end
    if pl < 0 then
        pl = 0
    end
    ipc.writeLvar('PedestalLightKnob', pl)
    if ipc.get("silence") == 0 then
        A182_PedestalLight_show ()
    end
end

---

function A182_PedestalAndGlare_show ()
     PedL = round((ipc.readLvar('PedestalLightKnob')/32)*100)
     GlarL = round((ipc.readLvar('GlareshieldLightKnob')/32)*100)
     PedGlareTxt = round((PedL + GlarL)/2)
     DspShow ("Glre", PedGlareTxt .. "%", "Ped+Glre", PedGlareTxt .. "%")
end

function A182_PedestalAndGlare_plus ()
    ipc.set("silence", 1)
    A182_GlareshieldLight_plus ()
    A182_PedestalLight_plus ()
    A182_PedestalAndGlare_show ()
    ipc.set("silence", 0)
end

function A182_PedestalAndGlare_plusfast ()
    ipc.set("silence", 1)
    A182_GlareshieldLight_plusfast ()
    A182_PedestalLight_plusfast ()
    A182_PedestalAndGlare_show ()
    ipc.set("silence", 0)
end

function A182_PedestalAndGlare_minus ()
    ipc.set("silence", 1)
    A182_GlareshieldLight_minus ()
    A182_PedestalLight_minus ()
    A182_PedestalAndGlare_show ()
    ipc.set("silence", 0)
end

function A182_PedestalAndGlare_minusfast ()
    ipc.set("silence", 1)
    A182_GlareshieldLight_minusfast ()
    A182_PedestalLight_minusfast ()
    A182_PedestalAndGlare_show ()
    ipc.set("silence", 0)
end

-- ## De Ice ###############

function A182_PitotHeat_on ()
    DeIce_PITOT_on ()
end

function A182_PitotHeat_off ()
    DeIce_PITOT_off ()
end

function A182_PitotHeat_toggle ()
    DeIce_PITOT_toggle ()
end

function A182_WindowDefrost_inc ()
	WDef = ipc.readLvar("WindowDefrosterControlKnob")
    WDef = WDef + 5
    if WDef > 100 then WDef = 100 end
	ipc.writeLvar("WindowDefrosterControlKnob", WDef)
	A182_WindowDefrost_show ()
end

function A182_WindowDefrost_incfast ()
	WDef = ipc.readLvar("WindowDefrosterControlKnob")
    WDef = WDef + 10
    if WDef > 100 then WDef = 100 end
	ipc.writeLvar("WindowDefrosterControlKnob", WDef)
	A182_WindowDefrost_show ()
end

function A182_WindowDefrost_dec ()
	WDef = ipc.readLvar("WindowDefrosterControlKnob")
    WDef = WDef - 5
    if WDef <= 0 then WDef = 0 end
	ipc.writeLvar("WindowDefrosterControlKnob", WDef)
	A182_WindowDefrost_show ()
end

function A182_WindowDefrost_decfast ()
	WDef = ipc.readLvar("WindowDefrosterControlKnob")
    WDef = WDef - 10
    if WDef <= 0 then WDef = 0 end
	ipc.writeLvar("WindowDefrosterControlKnob", WDef)
	A182_WindowDefrost_show ()
end

function A182_WindowDefrost_show ()
    WDef = ipc.readLvar("WindowDefrosterControlKnob")
	DspShow("WDef", WDef .. '%', 'Win.Defr', '  ' .. WDef .. '%')
end

-- ## CowlFlap ###############

function A2A_CowlFlap_show ()
    CFstate = round(ipc.readLvar("Eng1_CowlFlapsLever"))
    DspShow ("Cowl", CFstate .. "%")
end

function A2A_CowlFlap_inc ()
    CFvar = round(ipc.readLvar("Eng1_CowlFlapsLever"))
    if CFvar < 100 then CFvar = CFvar + 1 end
    if CFvar >= 100 then CFvar = 100 end
    ipc.writeLvar("Eng1_CowlFlapsLever", CFvar)
end

function A2A_CowlFlap_incfast ()
    CFvar = round(ipc.readLvar("Eng1_CowlFlapsLever"))
    if CFvar < 100 then CFvar = CFvar + 10 end
    if CFvar >= 100 then CFvar = 100 end
    ipc.writeLvar("Eng1_CowlFlapsLever", CFvar)
end

function A2A_CowlFlap_dec ()
    CFvar = round(ipc.readLvar("Eng1_CowlFlapsLever"))
    if CFvar > 0 then CFvar = CFvar - 1 end
    if CFvar <= 0 then CFvar = 0 end
    ipc.writeLvar("Eng1_CowlFlapsLever", CFvar)
end

function A2A_CowlFlap_decfast ()
    CFvar = round(ipc.readLvar("Eng1_CowlFlapsLever"))
    if CFvar > 0 then CFvar = CFvar - 10 end
    if CFvar <= 0 then CFvar = 0 end
    ipc.writeLvar("Eng1_CowlFlapsLever", CFvar)
end

function A2A_CowlFlap_closed ()
    CFvar = 0
    ipc.writeLvar("Eng1_CowlFlapsLever", CFvar)
end

function A2A_CowlFlap_50 ()
    CFvar = 50
    ipc.writeLvar("Eng1_CowlFlapsLever", CFvar)
end

function A2A_CowlFlap_open ()
    CFvar = 100
    ipc.writeLvar("Eng1_CowlFlapsLever", CFvar)
end

-- ## Cabin temperature

function A182_CabinHeat_inc ()
	local t = ipc.readLvar("CabinTempControl")
    t = t + 5
    if t > 100 then t = 100 end
	ipc.writeLvar("CabinTempControl", t)
	A182_CabinHeat_show ()
end

function A182_CabinHeat_incfast ()
	local t = ipc.readLvar("CabinTempControl")
    t = t + 10
    if t > 100 then t = 100 end
	ipc.writeLvar("CabinTempControl", t)
	A182_CabinHeat_show ()
end

function A182_CabinHeat_dec ()
	local t = ipc.readLvar("CabinTempControl")
    t = t - 5
    if t < 0 then t = 0 end
	ipc.writeLvar("CabinTempControl", t)
	A182_CabinHeat_show ()
end

function A182_CabinHeat_decfast ()
	local t = ipc.readLvar("CabinTempControl")
    t = t - 10
    if t < 0 then t = 0 end
	ipc.writeLvar("CabinTempControl", t)
	A182_CabinHeat_show ()
end

function A182_CabinHeat_show ()
    local t = ipc.readLvar("CabinTempControl")
	DspShow("HEAT", t .. '%', 'Cab.Heat', '  ' .. t .. '%')
end

function A182_CabinVent_inc ()
	local t = ipc.readLvar("CabinVent")
    t = t + 5
    if t > 100 then t = 100 end
	ipc.writeLvar("CabinVent", t)
	A182_CabinVent_show ()
end

function A182_CabinVent_incfast ()
	local t = ipc.readLvar("CabinVent")
    t = t + 10
    if t > 100 then t = 100 end
	ipc.writeLvar("CabinVent", t)
	A182_CabinVent_show ()
end

function A182_CabinVent_dec ()
	local t = ipc.readLvar("CabinVent")
    t = t - 5
    if t < 0 then t = 0 end
	ipc.writeLvar("CabinVent", t)
	A182_CabinVent_show ()
end

function A182_CabinVent_decfast ()
	local t = ipc.readLvar("CabinVent")
    t = t - 10
    if t < 0 then t = 0 end
	ipc.writeLvar("CabinVent", t)
	A182_CabinVent_show ()
end

function A182_CabinVent_show ()
    local t = ipc.readLvar("CabinVent")
	DspShow("VENT", t .. '%', 'Cab.Vent', '  ' .. t .. '%')
end

-- ## Davtron ###############

function A2A_Davtron_OatVolts ()
    ipc.writeLvar('ClockVolts', 1)
    ipc.sleep(150)
    ipc.writeLvar('ClockVolts', 0)
    DspShow ("Oat", "Volt", "Davtron", "Oat Volts")
end

function A2A_Davtron_Select ()
    ipc.writeLvar('ClockSelect', 1)
    ipc.sleep(150)
    ipc.writeLvar('ClockSelect', 0)
    DspShow ("Sel", "ect", "Davtron", "Select")
end

function A2A_Davtron_Control ()
    ipc.writeLvar('ClockControl', 1)
    ipc.sleep(150)
    ipc.writeLvar('ClockControl', 0)
    DspShow ("Cont", "rol", "Davtron", "Control")
end

-- ## Others ###############

function A2A_PopUp_2D_GPS ()
    GPStype = ipc.readLvar("GPStype")
    if GPStype == 1 then
        ipc.control(66506, 104)
        DspShow ("GNS", "250")
    elseif GPStype == 2 then
        ipc.control(66506, 105)
        DspShow ("GNS", "400")
    end
end
